==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/files/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 8287 2011-10-12 12:03:09Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 3.7.29 
// Author : Lionel JULLIEN
// Date : September, 27 2011
//
/////////////////////////////////////////////////////////////////////////////////

GO.files.lang.files='Fichiers';
GO.files.lang.template = 'Modèle'
GO.files.lang.manageTemplates = 'Gérer les modèles';
GO.files.lang.downloadTemplate = 'Télécharger le modèle';
GO.files.lang.enterName = 'Saisir un nom';
GO.files.lang.pleaseEnterName = 'Veuillez saisir un nom';
GO.files.lang.pleaseEnterNameArchive = 'Veuillez saisir un nom pour l\'archive';
GO.files.lang.startTransfer = 'Débuter le transfert';
GO.files.lang.addFolder = 'Ajouter un dossier';
GO.files.lang.errorOneItem = 'Veuillez sélectionner un seul élément';
GO.files.lang.activateSharing = 'Activer le partage';
GO.files.lang.notifyChanges = 'Me notifier les changements sur ce dossier';
GO.files.lang.comments = 'Commentaires';
GO.files.lang.downloadGOTA = 'Télécharger avec GOTA';
GO.files.lang.fileBrowser = 'Explorateur de fichiers';
GO.files.lang.thumbnails = 'Miniatures';
GO.files.lang.saveFile='Sauvegarder le fichier';
GO.files.lang.confirmOverwrite='Le fichier "{filename}" existe déjà, voulez vous l\'écraser ?';
GO.files.lang.file='Fichier';
GO.files.lang.emptyList='Liste vide';
GO.files.lang.newFiles='Nouveau';
GO.files.lang.olderVersions='Versions antérieures';
GO.files.lang.uploadProperties='Les propriétés ci-dessous seront appliquées à tous les fichiers envoyés avec l\'option "Petits fichiers"';
GO.files.lang.selectFiles = 'Sélectionner des fichiers';
GO.files.lang.fitImage='Adapter l\'image';
GO.files.lang.normalSize='Taille normale';
GO.files.lang.imageViewer='Visualiseur d\'images';
GO.files.lang.emailDownloadLink= 'Envoyer un lien de téléchargement';
GO.files.lang.expireTime= 'Date d\'expiration du lien';
GO.files.lang.newFolder = 'Nouveau dossier';
GO.files.lang.applyState = 'Appliquer les paramètres de visualisation actuels à tout le monde.';
GO.files.lang.stateLocked = 'Visualisation du dossier verrouiller par le proriétaire ou par l\'administrateur';
GO.files.lang.strDownloadActive = 'Lien de téléchargement externe activé';
GO.files.lang.downloadExpireTime='Le lien expirera après';
GO.files.lang.downloadUrl='URL';

==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/files/language/fr.js <==
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.js 12014 2012-09-20 16:01:48Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 4.0.99
// Author : Lionel JULLIEN / Boris HERBINIERE-SEVE
// Date : September, 20 2012
//
/////////////////////////////////////////////////////////////////////////////////

GO.files.lang.files='Fichiers';
GO.files.lang.template = 'Modèle'
GO.files.lang.manageTemplates = 'Gérer les modèles';
GO.files.lang.downloadTemplate = 'Télécharger le modèle';
GO.files.lang.enterName = 'Saisir un nom';
GO.files.lang.pleaseEnterName = 'Veuillez saisir un nom';
GO.files.lang.pleaseEnterNameArchive = 'Veuillez saisir un nom pour l\'archive';
GO.files.lang.startTransfer = 'Débuter le transfert';
GO.files.lang.addFolder = 'Ajouter un dossier';
GO.files.lang.errorOneItem = 'Veuillez sélectionner un seul élément';
GO.files.lang.activateSharing = 'Activer le partage';
GO.files.lang.notifyChanges = 'Me notifier les changements sur ce dossier';
GO.files.lang.comments = 'Commentaires';
GO.files.lang.downloadGOTA = 'Télécharger avec GOTA';
GO.files.lang.fileBrowser = 'Explorateur de fichiers';
GO.files.lang.thumbnails = 'Miniatures';
GO.files.lang.saveFile='Sauvegarder le fichier';
GO.files.lang.confirmOverwrite='Le fichier "{filename}" existe déjà, voulez vous l\'écraser ?';
GO.files.lang.file='Fichier';
GO.files.lang.emptyList='Liste vide';
GO.files.lang.newFiles='Nouveau';
GO.files.lang.olderVersions='Versions antérieures';
GO.files.lang.uploadProperties='Les propriétés ci-dessous seront appliquées à tous les fichiers envoyés avec l\'option "Petits fichiers"';
GO.files.lang.selectFiles = 'Sélectionner des fichiers';
GO.files.lang.fitImage='Adapter l\'image';
GO.files.lang.normalSize='Taille normale';
GO.files.lang.imageViewer='Visualiseur d\'images';
GO.files.lang.emailDownloadLink= 'Envoyer un lien de téléchargement';
GO.files.lang.expireTime= 'Date d\'expiration du lien';
GO.files.lang.newFolder = 'Nouveau dossier';
GO.files.lang.applyState = 'Appliquer les paramètres de visualisation actuels à tout le monde.';
GO.files.lang.stateLocked = 'Visualisation du dossier verrouillé par le proriétaire ou par l\'administrateur';
GO.files.lang.strDownloadActive = 'Lien de téléchargement externe activé';
GO.files.lang.downloadExpireTime='Le lien expirera après';
GO.files.lang.downloadUrl='URL';
GO.files.lang.categoriesFiles= 'Champs personnalisés pour les fichiers';
GO.files.lang.applyToCurrentFolder= 'N\'appliquer les modifications ci-dessus qu\'au contenu du dossier courant';
GO.files.lang.applyRecursively= 'Appliquer les modifications ci-dessus au contenu du dossier courant ainsi qu\'à ses sous-dossiers';
GO.files.lang.applyRecursivelyRUSure= 'Êtes-vous sur de vouloir appliquer les paramètres de ce champ personnalisé au contenu de TOUS les sous dossiers ? Cela peut avoir une grande influence si ce dossier comporte de nombreux sous dossiers.';
GO.files.lang.pleaseConfirm= 'Veuillez confirmer';
GO.files.lang.applyLimits= 'Ne pas afficher toutes les catégories des champs personnalisés';
GO.files.lang.undef= '-';
